@@ -120,19 +120,17 @@ class TSDUO(DEVftdi):
             return None
         a = data.split(REVT)[0]            
         first = a[2:]
-        if n == 1:
-            events.append(first)
-            return events
-        else:
+        events.append(first)
+        if n > 1:
             next = self.read(10 * maxlen)
-            if not next: return events
-            n1 = next.count(LEVT)
-            data += next
-            n += n1
-            evts = data.split(REVT)
-            for a in evts[1:-1]:
-                 e = a[2:]
-                 if e not in events:
-                      events.append(e)
-            logger.warning("Cut down data into %s fragments with %s different events",str(n),str(len(events)))
-            return events
+            if next:
+                n1 = next.count(LEVT)
+                data += next
+                n += n1
+                evts = data.split(REVT)
+                for a in evts[1:-1]:
+                    e = a[2:]
+                    if e not in events:
+                        events.append(e)
+                logger.warning("Cut down data into %s fragments with %s different events",str(n),str(len(events)))
+        return '|'.join(events)
