@@ -107,7 +107,7 @@ def x10pldecoder(targets,rejected=None,newids=None,rawevt=None):
                     flushx10evt(targets,hq)
                 hu = a
                 event = tstampdev(namedev) + ['device',protocol,hu,'NA']
-                postx10evt(targets,hq,event)
+                timerx10evt(targets,hq,event)
             elif p[1] == 1:
                 hfb = x10decode1(data)
                 if not hfb:
@@ -125,7 +125,7 @@ def x10pldecoder(targets,rejected=None,newids=None,rawevt=None):
                         logger.info( "Event X10 : %s", repr(data))
                         continue
                     a = hu
-                sendx10evt(targets,hq,a,b,ids,newids,rawevt,msgs)
+                postx10evt(targets,hq,a,b,ids,newids,rawevt,msgs)
             elif p[1] == 2:			#house + unit  - house + function
                 huhf = x10decode2(namedev.split(':')[1],data)
                 if not huhf:
@@ -136,7 +136,7 @@ def x10pldecoder(targets,rejected=None,newids=None,rawevt=None):
                 if huhf[0]:
                     hu = huhf[0]
                 hf = huhf[1]
-                sendx10evt(targets,hq,hu,hf[1],ids,newids,rawevt,msgs)
+                postx10evt(targets,hq,hu,hf[1],ids,newids,rawevt,msgs)
         else:
             logger.warning('First value read %s for the sequence differs with the length %s of incoming event',data[0],nb)
        	    if rejected: rejected.send(['DIFF_DECODE_huf'] + msgs)
@@ -144,15 +144,15 @@ def x10pldecoder(targets,rejected=None,newids=None,rawevt=None):
 
 
 def flushx10evt(targets,hq):
-    try:
+    if not hq.empty():
         evt = hq.get_nowait()
-    except QEmpty:
-        return
-    sendx10evt(targets,hq,evt)
+        for target in targets:
+            logger.debug("Function x10pldecoder for incomplete event %s",repr(evt))
+            target.send(evt)
     return
 
 
-def postx10evt(targets,hq,evt):
+def timerx10evt(targets,hq,evt):
     try:
         hq.put_nowait(evt)
     except:
@@ -163,7 +163,7 @@ def postx10evt(targets,hq,evt):
     return
 
 
-def sendx10evt(targets,hq,hu,evtf,ids,newids,rawevt,msgs):
+def postx10evt(targets,hq,hu,evtf,ids,newids,rawevt,msgs):
     namedev, protocol, data, p, model,hd,revt = msgs
     decevt = [protocol,hu,evtf]
     event = tstampdev(namedev) + ['device'] + decevt
@@ -185,4 +185,4 @@ def sendx10evt(targets,hq,hu,evtf,ids,newids,rawevt,msgs):
     ths = threading.enumerate()
     for th in ths:
         if 'Timer_x10pldecoder_' + evt[5] in repr(th): th.cancel()
-    return
\ No newline at end of file
+    return
