@@ -77,9 +77,6 @@ def RFXCOMparser(decoders,rejected=None):
             continue
         msgs[1] = hdps[hdp][0]		#protocol
         logger.debug("%s",repr(msgs))
-        decnames = hdps[hdp][1].split()
-        for decname in decnames:
-            for target in decoders:
-                if decname == target.__name__:
-                     logger.debug("Data sent to decoder %s",target.__name__)
-                     target.send(msgs)
+        for target in decoders:
+            logger.debug("Data sent to %s",repr(target))
+            target.send(msgs)
