@@ -59,18 +59,19 @@ def item2msgs(item):
 @coroutine
 def TSDUOparser(decoders,rejected=None):
     """
-    item = [namedev,[events]]
-    cut events (if many) befor send to TSDUOparser1
+    item = [namedev,events]
+    split events (if several) before sending to TSDUOparser1
     """
     while True:
         events = (yield)
         logger.debug("Event receive %s",repr(events))
-        #['TSD0:TSDUO',['protocol:arctech;model:selflearning;data:0x1FF3BAB0',]]
-        if isinstance(events[1],list):
-            for event in events[1]:
+        #['TSD0:TSDUO','protocol:arctech;model:selflearning;data:0x1FF3BAB0|protocol:arctech;model:selflearning;data:0x1FF3BAB0']
+        evts = events[1].split('|')
+        if len(evts) > 1:
+            for event in evts:
                 TSDUOparser1(decoders,rejected=None).send([events[0],event])
         else:
-            TSDUOparser1(decoders,rejected=None).send([events[0],events[1]])
+            TSDUOparser1(decoders,rejected=None).send(events)
  
 
 @my_fctname
@@ -96,10 +97,7 @@ def TSDUOparser1(decoders,rejected=None):
         msgs.append(hdps[hdp][1])	#Header 
         msgs.append(item[1])	#raw evt 
         logger.debug("%s",repr(msgs))
-        decnames = hdps[hdp][0].split()
-        for decname in decnames:
-            for target in decoders:
-                if decname == target.__name__:
-                    logger.debug("Data sent to %s in %s",target.__name__,repr(decnames))
-                    target.send(msgs)
+        for target in decoders:
+            logger.debug("Data sent to %s",repr(target))
+            target.send(msgs)
 
